==> ruby-rspec-rails_5.0.2.orig.tar.gz: rspec-rails-5.0.2/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

<!--

Below are a few steps it'd be super if you could follow.
If you can't do all of these, don't worry, but if you can it'll help us
resolve your bug faster!

-->

## What Ruby, Rails and RSpec versions are you using?

Ruby version:
Rails version:
RSpec version:

<!--

You can run

```
bundle exec ruby --version
bundle exec rails --version
bundle exec rspec --version
```

-->

## Observed behaviour

<!--
please provide a concise description of the behaviour you are observing with
RSpec and Rails
-->

## Expected behaviour

<!--
Please provide a description of what you expect to be happening, and how that
differs from the current behaviour.
-->

## Can you provide an example app?

<!--
This step is probably the most important in allowing us to quickly debug
your issue, and we typically ask that you follow these steps:

1. `rails new` an app at the specific version of ruby and rails that you are
   using
2. commit that app, so that we have the rails skeleton in a separate commit
3. Make all the changes necessary (adding RSpec, models, specs, controllers,
   etc) to reproduce the issue. There should be a failing test or tests that you
   expect to pass. We'll run `bundle exec rspec`, but if you can provide a
   readme with more detailed instructions that'd be amazing :)
4. Commit
5. Provide a link to a github repo, a description of the app and what you're expecting here
-->

==> ruby-rspec-rails_7.1.1.orig.tar.gz: rspec-rails-7.1.1/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

<!--

Below are a few steps it'd be super if you could follow.
If you can't do all of these, don't worry, but if you can it'll help us
resolve your bug faster!

-->

## What Ruby, Rails and RSpec versions are you using?

Ruby version:
Rails version:
RSpec version:

<!--

You can run

```
bundle exec ruby --version
bundle exec rails --version
bundle exec rspec --version
```

-->

## Observed behaviour

<!--
please provide a concise description of the behaviour you are observing with
RSpec and Rails
-->

## Expected behaviour

<!--
Please provide a description of what you expect to be happening, and how that
differs from the current behaviour.
-->

## Can you provide an example reproduction?

<!--
This step is probably the most important in allowing us to quickly debug
your issue, and we typically ask that you follow these steps:

1. `rails new` an app at the specific version of ruby and rails that you are
   using
2. commit that app, so that we have the rails skeleton in a separate commit
3. Make all the changes necessary (adding RSpec, models, specs, controllers,
   etc) to reproduce the issue. There should be a failing test or tests that you
   expect to pass. We'll run `bundle exec rspec`, but if you can provide a
   readme with more detailed instructions that'd be amazing :)
4. Commit
5. Provide a link to a github repo, a description of the app and what you're expecting here
-->
